<?php
/**
 * Audio Podcast Theme Customizer
 *
 * @package Audio Podcast
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function audio_podcast_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'audio_podcast_custom_controls' );

function audio_podcast_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'audio_podcast_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'audio_podcast_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'audio_podcast_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'audio-podcast' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'audio_podcast_left_right', array(
    	'title' => esc_html__( 'General Settings', 'audio-podcast' ),
		'panel' => 'audio_podcast_panel_id'
	) );

	$wp_customize->add_setting('audio_podcast_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));
	$wp_customize->add_control(new Audio_Podcast_Image_Radio_Control($wp_customize, 'audio_podcast_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','audio-podcast'),
        'description' => esc_html__('Here you can change the width layout of Website.','audio-podcast'),
        'section' => 'audio_podcast_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('audio_podcast_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));
	$wp_customize->add_control('audio_podcast_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','audio-podcast'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','audio-podcast'),
        'section' => 'audio_podcast_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','audio-podcast'),
            'Right Sidebar' => esc_html__('Right Sidebar','audio-podcast'),
            'One Column' => esc_html__('One Column','audio-podcast'),
            'Grid Layout' => esc_html__('Grid Layout','audio-podcast')
        ),
	) );

	$wp_customize->add_setting('audio_podcast_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));
	$wp_customize->add_control('audio_podcast_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','audio-podcast'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','audio-podcast'),
        'section' => 'audio_podcast_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','audio-podcast'),
            'Right_Sidebar' => esc_html__('Right Sidebar','audio-podcast'),
            'One_Column' => esc_html__('One Column','audio-podcast')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'audio_podcast_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'audio_podcast_customize_partial_audio_podcast_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'audio_podcast_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','audio-podcast' ),
		'section' => 'audio_podcast_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'audio_podcast_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'audio_podcast_customize_partial_audio_podcast_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'audio_podcast_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','audio-podcast' ),
		'section' => 'audio_podcast_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'audio_podcast_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','audio-podcast' ),
        'section' => 'audio_podcast_left_right'
    )));

	$wp_customize->add_setting('audio_podcast_preloader_bg_color', array(
		'default'           => '#1b2039',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'audio_podcast_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'audio-podcast'),
		'section'  => 'audio_podcast_left_right',
	)));

	$wp_customize->add_setting('audio_podcast_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'audio_podcast_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'audio-podcast'),
		'section'  => 'audio_podcast_left_right',
	)));

	// Top Bar
	$wp_customize->add_section( 'audio_podcast_top_bar' , array(
    	'title' => esc_html__( 'Top Bar', 'audio-podcast' ),
		'panel' => 'audio_podcast_panel_id'
	) );

	$wp_customize->add_setting('audio_podcast_topbar_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('audio_podcast_topbar_text',array(
		'label'	=> esc_html__('Add Topbar Text','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('audio_podcast_topbar_support_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('audio_podcast_topbar_support_link',array(
		'label'	=> esc_html__('Add Support Link','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_top_bar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('audio_podcast_topbar_wishlist_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('audio_podcast_topbar_wishlist_link',array(
		'label'	=> esc_html__('Add Wishlist Link','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_top_bar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('audio_podcast_topbar_myaccount_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('audio_podcast_topbar_myaccount_link',array(
		'label'	=> esc_html__('Add My Account Link','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_top_bar',
		'type'=> 'url'
	));

	//Slider
	$wp_customize->add_section( 'audio_podcast_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'audio-podcast' ),
		'panel' => 'audio_podcast_panel_id'
	) );

	$wp_customize->add_setting( 'audio_podcast_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ));  
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','audio-podcast' ),
      'section' => 'audio_podcast_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('audio_podcast_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'audio_podcast_customize_partial_audio_podcast_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'audio_podcast_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'audio_podcast_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'audio_podcast_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'audio-podcast' ),
			'description' => __('Slider image size (1500 x 540)','audio-podcast'),
			'section'  => 'audio_podcast_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting('audio_podcast_slider_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('audio_podcast_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => __( 'EXPLORE ALL', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_slidersettings',
		'type'=> 'text'
	));

	//content layout
	$wp_customize->add_setting('audio_podcast_slider_content_option',array(
        'default' => 'Right',
        'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));
	$wp_customize->add_control(new Audio_Podcast_Image_Radio_Control($wp_customize, 'audio_podcast_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','audio-podcast'),
        'section' => 'audio_podcast_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'audio_podcast_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'audio_podcast_sanitize_number_range'
	) );
	$wp_customize->add_control( 'audio_podcast_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','audio-podcast' ),
		'section'     => 'audio_podcast_slidersettings',
		'type'        => 'range',
		'settings'    => 'audio_podcast_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('audio_podcast_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));

	$wp_customize->add_control( 'audio_podcast_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','audio-podcast' ),
	'section'     => 'audio_podcast_slidersettings',
	'type'        => 'select',
	'settings'    => 'audio_podcast_slider_opacity_color',
	'choices' => array(
		'0' =>  esc_attr('0','audio-podcast'),
		'0.1' =>  esc_attr('0.1','audio-podcast'),
		'0.2' =>  esc_attr('0.2','audio-podcast'),
		'0.3' =>  esc_attr('0.3','audio-podcast'),
		'0.4' =>  esc_attr('0.4','audio-podcast'),
		'0.5' =>  esc_attr('0.5','audio-podcast'),
		'0.6' =>  esc_attr('0.6','audio-podcast'),
		'0.7' =>  esc_attr('0.7','audio-podcast'),
		'0.8' =>  esc_attr('0.8','audio-podcast'),
		'0.9' =>  esc_attr('0.9','audio-podcast')
	),
	));

	//Slider height
	$wp_customize->add_setting('audio_podcast_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('audio_podcast_slider_height',array(
		'label'	=> __('Slider Height','audio-podcast'),
		'description'	=> __('Specify the slider height (px).','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_slidersettings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'audio_podcast_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'audio_podcast_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','audio-podcast'),
		'section' => 'audio_podcast_slidersettings',
		'type'  => 'text',
	) );

	// Professionals
	$wp_customize->add_section('audio_podcast_player_section',array(
		'title'	=> __('Player Section','audio-podcast'),
		'description' => __('Select the Page to display player.','audio-podcast'),
		'panel' => 'audio_podcast_panel_id',
	));

	$wp_customize->add_setting( 'audio_podcast_player_page', array(
		'default'           => '',
		'sanitize_callback' => 'audio_podcast_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'audio_podcast_player_page', array(
		'label'    => __( 'Select Page of Player', 'audio-podcast' ),
		'section'  => 'audio_podcast_player_section',
		'type'     => 'dropdown-pages'
	) );

	//Blog Post
	$wp_customize->add_panel( 'audio_podcast_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'audio-podcast' ),
		'panel' => 'audio_podcast_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'audio_podcast_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'audio-podcast' ),
		'panel' => 'audio_podcast_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('audio_podcast_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'audio_podcast_Customize_partial_audio_podcast_toggle_postdate', 
	));

	$wp_customize->add_setting( 'audio_podcast_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','audio-podcast' ),
        'section' => 'audio_podcast_post_settings'
    )));

    $wp_customize->add_setting( 'audio_podcast_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_toggle_author',array(
		'label' => esc_html__( 'Author','audio-podcast' ),
		'section' => 'audio_podcast_post_settings'
    )));

    $wp_customize->add_setting( 'audio_podcast_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_toggle_comments',array(
		'label' => esc_html__( 'Comments','audio-podcast' ),
		'section' => 'audio_podcast_post_settings'
    )));

    $wp_customize->add_setting( 'audio_podcast_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_toggle_time',array(
		'label' => esc_html__( 'Time','audio-podcast' ),
		'section' => 'audio_podcast_post_settings'
    )));

    $wp_customize->add_setting( 'audio_podcast_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
	));
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','audio-podcast' ),
		'section' => 'audio_podcast_post_settings'
    )));

    $wp_customize->add_setting( 'audio_podcast_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
	));
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_toggle_tags', array(
		'label' => esc_html__( 'Tags','audio-podcast' ),
		'section' => 'audio_podcast_post_settings'
    )));

    $wp_customize->add_setting( 'audio_podcast_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'audio_podcast_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'audio_podcast_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','audio-podcast' ),
		'section'     => 'audio_podcast_post_settings',
		'type'        => 'range',
		'settings'    => 'audio_podcast_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('audio_podcast_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('audio_podcast_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','audio-podcast'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','audio-podcast'),
		'section'=> 'audio_podcast_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('audio_podcast_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));
	$wp_customize->add_control('audio_podcast_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','audio-podcast'),
        'section' => 'audio_podcast_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','audio-podcast'),
            'Excerpt' => esc_html__('Excerpt','audio-podcast'),
            'No Content' => esc_html__('No Content','audio-podcast')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'audio_podcast_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'audio-podcast' ),
		'panel' => 'audio_podcast_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'audio_podcast_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'audio_podcast_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'audio_podcast_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','audio-podcast' ),
		'section'     => 'audio_podcast_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('audio_podcast_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'audio_podcast_Customize_partial_audio_podcast_button_text', 
	));

    $wp_customize->add_setting('audio_podcast_button_text',array(
		'default'=> esc_html__('Read More','audio-podcast'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('audio_podcast_button_text',array(
		'label'	=> esc_html__('Add Button Text','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'audio_podcast_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'audio-podcast' ),
		'panel' => 'audio_podcast_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('audio_podcast_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'audio_podcast_Customize_partial_audio_podcast_related_post_title', 
	));

    $wp_customize->add_setting( 'audio_podcast_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ) );
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_related_post',array(
		'label' => esc_html__( 'Related Post','audio-podcast' ),
		'section' => 'audio_podcast_related_posts_settings'
    )));

    $wp_customize->add_setting('audio_podcast_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('audio_podcast_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('audio_podcast_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'audio_podcast_sanitize_number_absint'
	));
	$wp_customize->add_control('audio_podcast_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_related_posts_settings',
		'type'=> 'number'
	));

	//Responsive Media Settings
	$wp_customize->add_section('audio_podcast_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','audio-podcast'),
		'panel' => 'audio_podcast_panel_id',
	));

    $wp_customize->add_setting( 'audio_podcast_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ));  
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','audio-podcast' ),
      	'section' => 'audio_podcast_responsive_media'
    )));

    $wp_customize->add_setting( 'audio_podcast_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ));  
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','audio-podcast' ),
      	'section' => 'audio_podcast_responsive_media'
    )));

    $wp_customize->add_setting( 'audio_podcast_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ));  
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','audio-podcast' ),
      	'section' => 'audio_podcast_responsive_media'
    )));

    $wp_customize->add_setting('audio_podcast_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Audio_Podcast_Fontawesome_Icon_Chooser(
        $wp_customize,'audio_podcast_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','audio-podcast'),
		'transport' => 'refresh',
		'section'	=> 'audio_podcast_responsive_media',
		'setting'	=> 'audio_podcast_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('audio_podcast_res_menu_close_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Audio_Podcast_Fontawesome_Icon_Chooser(
        $wp_customize,'audio_podcast_res_menu_close_icon',array(
		'label'	=> __('Add Close Menu Icon','audio-podcast'),
		'transport' => 'refresh',
		'section'	=> 'audio_podcast_responsive_media',
		'setting'	=> 'audio_podcast_res_menu_close_icon',
		'type'		=> 'icon'
	)));

	//Footer Text
	$wp_customize->add_section('audio_podcast_footer',array(
		'title'	=> esc_html__('Footer Settings','audio-podcast'),
		'panel' => 'audio_podcast_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('audio_podcast_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'audio_podcast_Customize_partial_audio_podcast_footer_text', 
	));
	
	$wp_customize->add_setting('audio_podcast_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('audio_podcast_footer_text',array(
		'label'	=> esc_html__('Copyright Text','audio-podcast'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2020, .....', 'audio-podcast' ),
        ),
		'section'=> 'audio_podcast_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('audio_podcast_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));
	$wp_customize->add_control(new Audio_Podcast_Image_Radio_Control($wp_customize, 'audio_podcast_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','audio-podcast'),
        'section' => 'audio_podcast_footer',
        'settings' => 'audio_podcast_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'audio_podcast_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'audio_podcast_switch_sanitization'
    ));  
    $wp_customize->add_control( new Audio_Podcast_Toggle_Switch_Custom_Control( $wp_customize, 'audio_podcast_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','audio-podcast' ),
      	'section' => 'audio_podcast_footer'
    )));

     //Selective Refresh
	$wp_customize->selective_refresh->add_partial('audio_podcast_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'audio_podcast_Customize_partial_audio_podcast_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('audio_podcast_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'audio_podcast_sanitize_choices'
	));
	$wp_customize->add_control(new Audio_Podcast_Image_Radio_Control($wp_customize, 'audio_podcast_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','audio-podcast'),
        'section' => 'audio_podcast_footer',
        'settings' => 'audio_podcast_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'audio_podcast_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Audio_Podcast_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Audio_Podcast_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Audio_Podcast_Customize_Section_Pro( $manager,'audio_podcast_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'PODCAST PRO', 'audio-podcast' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'audio-podcast' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/audio-podcast-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Audio_Podcast_Customize_Section_Pro($manager,'audio_podcast_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'audio-podcast' ),
			'pro_text' => esc_html__( 'DOCS', 'audio-podcast' ),
			'pro_url'  => admin_url('themes.php?page=audio_podcast_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'audio-podcast-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'audio-podcast-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Audio_Podcast_Customize::get_instance();